@@ -31,9 +31,5 @@ pub fn fce_test_impl(attrs: TokenStream, input: TokenStream) -> TResult<TokenStr
 
     let func_item = syn::parse2::<syn::ItemFn>(input)?;
 
-    let t = generate_test_glue_code(func_item, attrs);
-    let y = t.unwrap();
-    println!("result:\n{}", y);
-
-    Ok(y)
+    generate_test_glue_code(func_item, attrs)
 }
